---
title: <span class="badge builder"></span> ExtendedStat
---
# <span class="badge builder"></span> ExtendedStat

## Constructor

```python
ExtendedStat()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ExtendedStat
```

### <span class="badge object-method"></span> label

```python
def label(label: str) -> typing.Self
```

### <span class="badge object-method"></span> value

```python
def value(value: elasticsearch.ExtendedStatMetaType) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExtendedStat](./object-ExtendedStat.md)
